import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JColorChooser;
import javax.swing.JComboBox;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JPopupMenu;


class DropDownButton extends JPanel
{
	private static final long serialVersionUID = 1L;
	JMenuItem menuItem;
	JMenuItem menuButton;
	JPopupMenu popupMenu;
	JColorChooser colorChooser;
	JComboBox<JMenuItem> b;
	List<JMenuItem> items;

	public DropDownButton(ImageIcon icon)
	{
		this(new JMenuItem(icon), null);
	}

	public DropDownButton(ImageIcon icon, JColorChooser chooser)
	{
		this(new JMenuItem(icon), chooser);
	}

	private DropDownButton(JMenuItem menuItem, JColorChooser chooser)
	{
		this.popupMenu = new JPopupMenu();
		this.popupMenu.setLayout(new BoxLayout(this.popupMenu, BoxLayout.Y_AXIS));
		if (chooser != null)
		{
			colorChooser = chooser;
			popupMenu.add(colorChooser);
		}

		this.menuItem = menuItem;
		this.items = new ArrayList<JMenuItem>();

		setLayout(new BorderLayout());
		menuItem.setBorderPainted(false);
		add(BorderLayout.CENTER, menuItem);
		menuButton = new JMenuItem(new ImageIcon(DemoForm.class.getResource("/com/mindfusion/spreadsheet/images/down.png")));
		menuButton.setPreferredSize(new Dimension(15, 10));
		add(BorderLayout.EAST, menuButton);
		menuButton.setBorderPainted(false);

		MouseAdapter ma = new MouseAdapter()
		{
			public void mousePressed(MouseEvent me)
			{
				if (me.getSource() == menuItem)
				{
					menuButton.setSelected(true);
				}
			}

			public void mouseReleased(MouseEvent me)
			{
				if (me.getSource() == menuItem)
				{
					menuButton.setSelected(false);
				}
			}

			public void mouseEntered(MouseEvent me)
			{
				setRolloverBorder();
			}

			public void mouseExited(MouseEvent me)
			{
				unsetRolloverBorder();
			}
		};

		menuItem.addMouseListener(ma);
		menuButton.addMouseListener(ma);

		menuButton.addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent ae)
			{
				popupMenu.setAutoscrolls(true);
				popupMenu.show(menuItem, 0, menuItem.getSize().height);
			}
		});
	}

	public void addActionListener(ActionListener l)
	{
		menuButton.addActionListener(l);
	}

	public void addMenuItem(JMenuItem item)
	{
		popupMenu.add(item);
		items.add(item);
	}

	protected void setRolloverBorder()
	{
		menuItem.setBorderPainted(true);
		menuButton.setBorderPainted(true);
	}

	protected void unsetRolloverBorder()
	{
		menuItem.setBorderPainted(false);
		menuButton.setBorderPainted(false);
	}
}